OwnerLookup

Enum OwnerLookup 

pub enum OwnerLookup {
    OwnerId(OwnerId),
    AnimalId(AnimalId),
    ReservationId(ReservationId),
    Phone(SensitiveLookup),
    Email(SensitiveLookup),
}
Typed Gingr owner lookup strategies, separating sensitive search inputs from normal IDs.

Variants



OwnerId(OwnerId)

Lookup uses a Gingr owner identifier.



AnimalId(AnimalId)

Lookup uses a Gingr animal identifier.



ReservationId(ReservationId)

Lookup uses a Gingr reservation identifier.



Phone(SensitiveLookup)

Lookup uses an owner phone number and should be treated as sensitive.



Email(SensitiveLookup)

Lookup uses an owner email address and should be treated as sensitive.